/**************************************************************************
*************                                                 *************
*******                        SUCOMA32.HX                       **********
*************                                                 *************
***************************************************************************
*                                                                         *
*                            Copyright 2001 (c)                           *
*                              by Moeller GmbH                            *
*                                                                         *
*                                                                         *
*                             SUCOMA32 V3.20                              *
*                  32 Bit DLL for Windows 95/98/NT 4.0                    *
*                                                                         *
*                                                                         *
*                                                                         *
***************************************************************************/

#ifndef sucoma32_hx
#define sucoma32_hx


#ifdef __cplusplus              
    extern "C"  {
#endif                     
   

/* Errormessages: PS40_Link */
#define    SUCOM_OK                        (0)    /* Function works correctly */
#define    SUCOM_COMM_ERROR                (1)    /* Reception error like Parity, Overrun ... */
#define    SUCOM_COM_PORT_NOT_FOUND        (2)    /* The interface does not exist or is faulty */
#define    SUCOM_ERROR_OPEN_COM_PORT       (3)    /* Internal PC interface error */
#define    SUCOM_COM_PORT_ALREADY_OPEN     (4)    /* The interface port is used by another application */
#define    SUCOM_PARAMETER_ERROR           (5)    /* At least one parameter is not valid */
#define    SUCOM_ERROR_ON_WRITING          (6)    /* A general write error has occured */
#define    SUCOM_ERROR_ON_READING          (7)    /* A general read error has occured */
#define    SUCOM_WRONG_ANSWER              (8)    /* Error reading PLC (Wrong PLC Typ, CRC Error, Not a KM PLC device ?!) */
#define    SUCOM_READING_TIMEOUT           (9)    /* TimeOut has occured reading the PLC */
#define    SUCOM_WRITING_TIMEOUT           (10)   /* TimeOut has occured writing the PLC */
#define    SUCOM_ERROR_INIT_TIMEOUT_VALUES (11)   /* Internal initialisation error of the interface */
#define    SUCOM_TOO_MUCH_MARKER           (12)   /* The requested marker data is outside the PLC marker range */
#define    SUCOM_NO_EXT_DLL_FOUND          (13)   /* A extension DLL couldnt be found */
#define    SUCOM_INVALID_DLL               (14)   /* A extension DLL is invalid (doesnt contain Func entrypoint) */
#define    SUCOM_BREAK_BY_USER             (15)   /* The operation is canceled due to a user break in callback fct */


/* Errormessages: PS40_Modem_Link */
#define    SUCOM_BUSY                      (300)   /* No connection established: line is busy */
#define    SUCOM_NO_ANSWER                 (301)   /* No connection established: no answer from remote party */
#define    SUCOM_NO_DIALTONE               (302)   /* No connection established: no dialtone available */
#define    SUCOM_DISCONNECT                (303)   /* No connection established or the remote party has disconnected from the call */
#define    SUCOM_UNAVAILABLE               (304)   /* No connection established: modem or line is unavailable .
                                                      The installation/configuration of the Modem failed or was cancelled by the user.
                                                      The Modem is switched off. */
#define    SUCOM_TAPI_DRIVER               (305)   /* Maybe not a actual TAPI Driver Version (UniModem) */
#define    SUCOM_TAPI_VERSION              (306)   /* Incompatible TAPI Version (Need TAPI V1.4 or greater) */


/* Errormessages: PS40_TCPIP_Link */
#define    SUCOM_EXTENSION_DLL_NOT_FOUND	(400)  /* A requested PS40_TCPIP_LINK technology DLL like the PS40_TCPIP_COBOX */
                                                   /* for the Lantronix CoBox device could not be found */
#define    SUCOM_WSASTARTUP_FAILED			(401)  /* Internal Windows error: The Windows socket services could not be started*/
#define    SUCOM_INVALID_SOCKET_DLL_VERSION	(402)  /* The file "Winsock.dll" is not version V2.0 or later */
#define    SUCOM_CREATE_SOCKET_FAILED		(403)  /* Internal Windows error! Could not create Windows socket */
#define    SUCOM_BIND_SOCKET_FAILED			(404)  /* Internal Windows error! The socket binding failed */
#define    SUCOM_SETSOCKOPT_FAILED			(405)  /* Internal Windows error! Could not set socket options */
#define    SUCOM_CONNECT_FAILED				(406)  /* Internal Windows error! A connection could not be established */
#define    SUCOM_CONNECT_REFUSED			(407)  /* Internal Windows error! A connection could not be established*/
#define    SUCOM_SHUTDOWN_CONNECTION_FAILED	(408)  /* Internal Windows error! The connections shutdown failed */
#define    SUCOM_CLOSE_CONNECTION_FAILED	(409)  /* Internal Windows error! The connection closing failed */
#define    SUCOM_PARAM_INTERFACE_FAILED		(410)  /* The Terminal interface could not be parameterised */
#define    SUCOM_INTERFACE_NOT_REACHEABLE	(411)  /* The Terminal interface is not responding*/
#define    SUCOM_INVALID_BAUDRATE_SETTING	(415)  /* Parameter error: The terminal device does not support this baudrate */
#define    SUCOM_INVALID_PORTNUMBER			(416)  /* Parameter error: The terminal device does not support this COM port */
#define    SUCOM_IP_ADDRESS_NOT_FOUND		(417)  /* The given IP Address is invalid and the symbolic name is not listed in the HOSTS file */
												   /*  ist nicht in HOSTS eingetragen */
#define    SUCOM_INVALID_PARAMETER			(418)  /* Parameter error: The specified IP address format is invalid. */
#define    SUCOM_TIMEOUT					(419)  /* The PLC (and therefore the CoBox too) is not responding during a data receive operation. */
#define    SUCOM_WRITE_FAILED				(420)  /* A general error during a data send operation has occurred. */
#define    SUCOM_READ_FAILED				(421)  /* A general error during a data receive operation has occurred. */
#define    SUCOM_CONNECTION_LOST			(422)  /* A successfully established connection is broken down, */
											       /* usually due to a network error (network cabling). */


/* Moeller PLC-typs */
#define    KM_PLC_PS3                      (5)    /* PS3 */
#define    KM_PLC_PS306                    (3)    /* PS306 */
#define    KM_PLC_PS316                    (3)    /* PS316 */
#define    KM_PLC_PS4_101                  (5)    /* PS4-101 */
#define    KM_PLC_PS4_111                  (5)    /* PS4-111 */
#define    KM_PLC_PS4_141                  (7)    /* PS4-141-MM1 */
#define    KM_PLC_PS4_151                  (7)    /* PS4-151-MM1 */
#define    KM_PLC_PS4_201                  (7)    /* PS4-201-MM1 */
#define    KM_PLC_PS4_271                  (7)    /* PS4-271-MM1 */
#define    KM_PLC_PS4_341                  (7)    /* PS4-341-MM1 */
#define    KM_PLC_PS416                    (3)    /* PS416-CPU-200/300/400 */


/* Binary IEC-Datatyps */
#define    KM_BIT_NAME                     "BOOL"    /* !!! ONLY FOR READING !!! */
#define    KM_BYTE_NAME                    "BYTE"
#define    KM_WORD_NAME                    "WORD"
#define    KM_LONG_NAME                    "LONG"

/* Integer IEC-Datatyps */
#define    KM_VB_BOOL_NAME                 "VBBOOL"  /* !!! ONLY FOR READING !!! */
#define    KM_VB_BYTE_NAME                 "VBBYTE"
#define    KM_VB_WORD_NAME                 "VBWORD"
#define    KM_VB_LONG_NAME                 "VBLONG"

#define    KM_VB_SINT_NAME                 "VBSINT"
#define    KM_VB_USINT_NAME                "VBUSINT"
#define    KM_VB_INT_NAME                  "VBINT"
#define    KM_VB_UINT_NAME                 "VBUINT"
#define    KM_VB_DINT_NAME                 "VBDINT"
#define    KM_VB_UDINT_NAME                "VBUDINT"


#define    KM_OPTION_MODEM_CALLBACK			"MODEM_CALLBACK"
#define    KM_OPTION_TCPIP_CALLBACK			"TCPIP_CALLBACK"


/* Modem connection through PS40_Modem_Link: Parameter for callback function */
#define    MODEM_DIAL_TONE 					(1)	  /* A dial tone is detected */
#define    MODEM_DIALING                    (2)	  /* The phone number will be dialed */
#define    MODEM_PROCEEDING                 (3)   /* The call is under way */
#define    MODEM_CONNECT                    (4)   /* A successful connection is established */
#define    MODEM_DISCONNECT                 (5)   /* The line is disconnected (remote or local) */
#define    MODEM_NO_CONNECTION              (6)   /* No connection could be established
                                                     (The appropriate function (e.g. openComDevice) 
												     will return with an error code. */


#define    TCPIP_OPEN_SEQ 					(1)	  /* Try opening a connection with given baudrate */
#define    TCPIP_START_SEQ 					(2)	  /* Start the automatic Baudrate setting sequence */
#define    TCPIP_END_SEQ 					(3)	  /* Successful ending the Baudrate setting sequence */
#define    TCPIP_SEQ_FAILED					(4)	  /* The Baudrate setting sequence failed*/



/****** Functions for the SUCOMA32.DLL for 32-Bit-Applications ******/
/******          useable for MS-WINDOWS 95/98/NT 4.0           ******/

#define KM_DLL_FCT_DEF    __declspec(dllexport) __stdcall 


typedef int (__stdcall *SUCOM_PROGRESS_FCT)( int xwProgress );




/* Read DLL-Version/Sring */
unsigned short KM_DLL_FCT_DEF getSucomVersion   (   char*            xpVersionBuffer );
unsigned short KM_DLL_FCT_DEF getVersion		(	char*			 xpExtensionName,
													char*			 xpVersion );

/* Write Data from PC -> PLC-Ram */
unsigned short KM_DLL_FCT_DEF writeDataToPLC    (   char*            xpComDevice,
                                                    char*            xpDataType,
                                                    unsigned short   xwStartAddress,
                                                    void*            xpDataToSend );

unsigned short KM_DLL_FCT_DEF writeDataToPLCex    ( char*            xpComDevice, 
                                                    int              xwPortID,
                                                    char*            xpDataType,
                                                    unsigned short   xwStartAddress,
                                                    unsigned short   xwNoOfElements,
                                                    void*            xpDataToSend );



/* Read Data from PLC-Ram -> PC */
unsigned short KM_DLL_FCT_DEF readDataFromPLC    (  char*            xpComDevice, 
                                                    char*            xpDataType,
                                                    unsigned short   xwStartAddress,
                                                    void*            xpReadData );

unsigned short KM_DLL_FCT_DEF readDataFromPLCex    (char*            xpComDevice, 
                                                    int              xwPortID,
                                                    char*            xpDataType,
                                                    unsigned short   xwStartAddress,
                                                    unsigned short   xwNoOfElements,
                                                    void*            xpReadData );



unsigned short KM_DLL_FCT_DEF openComDevice     (   char*            xpComDevice,
                                                    int*             xwPortID );
                                                                
unsigned short KM_DLL_FCT_DEF closeComDevice    (   int              xwPortID );

unsigned short KM_DLL_FCT_DEF setPLCType        (   unsigned short   xwPLCType );


unsigned short KM_DLL_FCT_DEF setSucomOptions	(	char*			xpOptionName,
													long			xpOptionValue );





/*                                                                              */
/****** Compatibility-Functions of the SUCOMA32.DLL for former 16-Bit-Apps ******/
/*                    !!!! Do not use for new Apps !!!!                        */

int KM_DLL_FCT_DEF             GetDLLVersion    (   char*      xpVersion );


char KM_DLL_FCT_DEF            SendCPUData      (   char*      xpComDevice,
                                                    int        xhComHandle,
                                                    int        xbInitCom,    
                                                    int        xwPLCType,
                                                    int        xwOperandType,
                                                    int        xwStartAddress,
                                                    int        xwNoOfWords,
                                                    void*      xpDataToSend );

char KM_DLL_FCT_DEF            ReadCPUData      (   char*      xpComDevice,
                                                    int        xhComHandle,
                                                    int        xbInitCom,    
                                                    int        xwPLCType,
                                                    int        xwOperandType,
                                                    int        xwStartAddress,
                                                    int        xwNoOfWords,
                                                    void*      xpReadData );

   
#ifdef __cplusplus                
    }
#endif


#endif  



/******************************** EOF: SUCOMA32.hx ******************************************/
